@@ -2,7 +2,7 @@ import json
 import logging
 from enum import Enum
 from functools import cached_property
-from typing import Any, ClassVar, Generator, Literal, Optional, Union
+from typing import Any, cast, ClassVar, Dict, Generator, List, Literal, Optional, Union
 
 from pydantic import BaseModel, Field
 
@@ -18,8 +18,12 @@ log = logging.getLogger(__name__)
 
 
 class _Attributes(BaseModel):
-    name: str
+    name: Optional[str] = None
     description: Optional[str] = None
+    organization: Optional[str] = None
+    department: Optional[str] = None
+    project: Optional[str] = None
+    modality: Optional[str] = None
 
 
 class _Relationships(BaseModel):
@@ -58,12 +62,13 @@ class Experiment(Container):
     def create(
         cls,
         *,
-        name: str,
+        name: Optional[str] = None,
         description: Optional[str] = None,
         template: Optional['Experiment'] = None,
         notebook: Optional[Notebook] = None,
-        digest: str = None,
+        digest: Optional[str] = None,
         force: bool = True,
+        attributes: Optional[Dict[str, Any]] = None,
     ) -> 'Experiment':
         """Create new Experiment in Signals Notebook
 
@@ -74,6 +79,7 @@ class Experiment(Container):
             notebook: notebook where create experiment
             digest: Indicate digest
             force: Force to create without doing digest check
+            attributes:
 
         Returns:
             Experiment
@@ -89,20 +95,13 @@ class Experiment(Container):
         request = _RequestPayload(
             data=_RequestBody(
                 type=cls._get_entity_type(),
-                attributes=_Attributes(
-                    name=name,
-                    description=description,
-                ),
+                attributes=_Attributes(name=name, description=description, **(attributes or {})),
                 relationships=relationships,
             )
         )
 
         log.debug('Creating Notebook for: %s', cls.__name__)
-        return super()._create(
-            digest=digest,
-            force=force,
-            request=request,
-        )
+        return cast('Experiment', super()._create(digest=digest, force=force, request=request))
 
     @cached_property
     def stoichiometry(self) -> Union[Stoichiometry, list[Stoichiometry]]:
@@ -160,12 +159,62 @@ class Experiment(Container):
         from signals_notebook.item_mapper import ItemMapper
 
         metadata = json.loads(fs_handler.read(fs_handler.join_path(path, 'metadata.json')))
-        experiment = cls.create(
-            notebook=parent, name=metadata['name'], description=metadata['description'], force=True
-        )
+        try:
+            experiment = cls.create(
+                notebook=parent,
+                name=metadata['name'],
+                description=metadata['description'],
+                force=True,
+                attributes=dict(
+                    organization=metadata['Organization'],
+                    project=metadata['Project'],
+                    modality=metadata['Modality'],
+                    department=metadata['Department'],
+                ),
+            )
+        except Exception as e:
+            log.error(str(e))
+            if 'According to template, name is auto generated, can not be specified' in str(e):
+                log.error('Retrying create')
+                experiment = cls.create(
+                    notebook=parent,
+                    description=metadata['description'],
+                    force=True,
+                    attributes=dict(
+                        organization=metadata['Organization'],
+                        project=metadata['Project'],
+                        modality=metadata['Modality'],
+                        department=metadata['Department'],
+                    ),
+                )
+            else:
+                raise e
         child_entities_folders = fs_handler.list_subfolders(path)
         for child_entity in child_entities_folders:
             child_entity_type = child_entity.split(':')[0]
-            ItemMapper.get_item_class(child_entity_type)._load(
-                fs_handler.join_path(path, child_entity), fs_handler, experiment
-            )
+            try:
+                ItemMapper.get_item_class(child_entity_type)._load(
+                    fs_handler.join_path(path, child_entity), fs_handler, experiment
+                )
+            except NotImplementedError:
+                log.error('Failed to load entity %s. Not supported' % child_entity_type)
+
+    def dump(self, base_path: str, fs_handler: FSHandler, alias: Optional[List[str]] = None) -> None:
+        metadata = {k: v for k, v in self.dict().items() if k in ('name', 'description', 'eid')}
+        self._reload_properties()
+        for prop in self._properties:
+            if prop.name in ('Department', 'Project', 'Modality', 'Organization'):
+                metadata[prop.name] = prop.value
+
+        fs_handler.write(
+            fs_handler.join_path(base_path, self.eid, 'metadata.json'),
+            json.dumps(metadata),
+            alias + [self.name, '__Metadata'] if alias else None,
+        )
+        for child in self.get_children():
+            try:
+                child.dump(
+                    fs_handler.join_path(base_path, self.eid), fs_handler, alias + [self.name] if alias else None
+                )
+            except Exception as e:
+                log.error(str(e))
