@@ -1,4 +1,5 @@
 import logging
+from enum import Enum
 from typing import ClassVar, Literal
 
 from pydantic import Field
@@ -12,6 +13,13 @@ log = logging.getLogger(__name__)
 
 
 class Word(ContentfulEntity):
+    class ContentType(str, Enum):
+        DOCX = 'application/vnd.openxmlformats-officedocument.wordprocessingml.document'
+        DOTX = 'application/vnd.openxmlformats-officedocument.wordprocessingml.template'
+        DOCM = 'application/vnd.ms-word.document.macroEnabled.12'
+        DOTM = 'application/vnd.ms-word.template.macroEnabled.12'
+        DOC = 'application/msword'
+
     type: Literal[EntityType.WORD] = Field(allow_mutation=False)
     _template_name: ClassVar = 'word.html'
 
@@ -20,23 +28,33 @@ class Word(ContentfulEntity):
         return EntityType.WORD
 
     @classmethod
-    def create(cls, *, container: Container, name: str, content: str = '', force: bool = True) -> Entity:
+    def create(
+        cls,
+        *,
+        container: Container,
+        name: str,
+        content_type: str = ContentType.DOCX,
+        content: bytes = b'',
+        force: bool = True,
+    ) -> Entity:
         """Create Word Entity
 
         Args:
             container: Container where create new Word
             name: file name
+            content_type: content type of Word entity
             content: Word content
             force: Force to post attachment
 
         Returns:
 
         """
+        cls.ContentType(content_type)
         log.debug('Create entity: %s with name: %s in Container: %s', cls.__name__, name, container.eid)
         return container.add_child(
             name=name,
-            content=content.encode('utf-8'),
-            content_type='application/vnd.openxmlformats-officedocument.wordprocessingml.document',
+            content=content,
+            content_type=content_type,
             force=force,
         )
 
